==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PercentChangeYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericYAxisDescriptionMetadata } from "./NumericYAxisDescriptionMetadata";
import { PercentChangeYAxisDescription } from "./PercentChangeYAxisDescription";
/**
 * @hidden
 */
export let PercentChangeYAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentChangeYAxisDescriptionMetadata extends Base {
        static b(a) {
            if (PercentChangeYAxisDescriptionMetadata.a == null) {
                PercentChangeYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentChangeYAxisDescriptionMetadata.c(PercentChangeYAxisDescriptionMetadata.a);
            }
            if (a.k(PercentChangeYAxisDescriptionMetadata.a)) {
                return;
            }
            a.ab(PercentChangeYAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericYAxisDescriptionMetadata.c(a);
        }
        static d(a) {
            PercentChangeYAxisDescriptionMetadata.b(a);
            a.ad("PercentChangeYAxis", () => new PercentChangeYAxisDescription());
            a.ac("PercentChangeYAxis", PercentChangeYAxisDescriptionMetadata.a);
        }
    }
    PercentChangeYAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentChangeYAxisDescriptionMetadata, 'PercentChangeYAxisDescriptionMetadata');
    PercentChangeYAxisDescriptionMetadata.a = null;
    return PercentChangeYAxisDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/PercentChangeYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericYAxisDescriptionMetadata } from "./NumericYAxisDescriptionMetadata";
import { PercentChangeYAxisDescription } from "./PercentChangeYAxisDescription";
/**
 * @hidden
 */
export let PercentChangeYAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentChangeYAxisDescriptionMetadata extends Base {
        static b(a) {
            if (PercentChangeYAxisDescriptionMetadata.a == null) {
                PercentChangeYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentChangeYAxisDescriptionMetadata.c(PercentChangeYAxisDescriptionMetadata.a);
            }
            if (a.k(PercentChangeYAxisDescriptionMetadata.a)) {
                return;
            }
            a.ac(PercentChangeYAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericYAxisDescriptionMetadata.c(a);
        }
        static d(a) {
            PercentChangeYAxisDescriptionMetadata.b(a);
            a.ae("PercentChangeYAxis", () => new PercentChangeYAxisDescription());
            a.ad("PercentChangeYAxis", PercentChangeYAxisDescriptionMetadata.a);
        }
    }
    PercentChangeYAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentChangeYAxisDescriptionMetadata, 'PercentChangeYAxisDescriptionMetadata');
    PercentChangeYAxisDescriptionMetadata.a = null;
    return PercentChangeYAxisDescriptionMetadata;
})();
